==> GOsa-1.0.0.tar.gz: gosa/main.php <==
<?php
/**************************************************************************
*                        GONICUS Server Administration                    *
*        Version 1.0.0  (C) 2002 Cajus Pollmeier <pollmeier@gonicus.de>   *
***************************************************************************
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation, version 2 of the License                *
*                                                                         *
***************************************************************************/

# Load session data and preset $parent_length
session_start ();
#error_reporting (65535);
error_reporting (0);
$parent_length= strlen (`pwd`);
header("Expires: Mon, 26 Jul 1997 05:00:00 GMT");
header("Last-Modified: " . gmdate("D, d M Y H:i:s") . " GMT"); 
header("Cache-Control: no-store, no-cache, must-revalidate");
header("Cache-Control: post-check=0, pre-check=0", false);
header("Pragma: no-cache");

print ("<script language=\"JavaScript\">\n");
print (" <!--\n");
print ("function showHelpPopup(page) {\n");
print (" window.open (page, 'newwindow', config='height=500, width=500, toolbar=no, menubar=no, scrollbars=yes, resizable=yes, location=no, directories=no, status=no');\n");
print ("}\n");
print (" -->\n");
print ("</script>\n");

# Redirect to login screen if not registered
if (!session_is_registered ("user")) {
	header ("Location: $admin_base/index.php");
	print ("\n\n");
	exit ();
}

# initialize side menu
if (!count($side_menu)){
        $side_menu= array ();
}

# Include menu subroutines
require ("include/setup.inc");
require ("include/common.inc");
require ("include/ldap.inc");
require ("include/menu.inc");
#require ("include/sieve-php.lib");

# Setup language and text domain for all plugins
if (!strlen($language)){
	$language=trim(get_language ($HTTP_ACCEPT_LANGUAGE));
}

putenv ("LANG=$language");
setlocale("LC_ALL", "");
bindTextDomain('main', './locale');
textDomain('main');
session_register ("language");

# Preset plugin to welcome.php
if (!isset ($plugin)) {
	$plugin= "welcome";
	$prtmode= false;
}

# Check for admin rights - only for the first time
if (!isset($isadmin)) {
	$isadmin= false;
	$isdepartmentadmin= false;
	if (!($ldap= ldap_con ($user,$password))) {
		print_red (_("Cannot bind to the ldap server: "));
		exit ();
	}

	# Try to write a dummy entry
	$entry= array ();
	$entry["objectclass"][]= "top";
	if (ldap_add ($ldap, "cn=admincheck,$LDAP_BASE", $entry)) {
		$isadmin= true;
		ldap_delete ($ldap, "cn=admincheck, $LDAP_BASE");
	}

	# is department admin?
	$sr=ldap_search ($ldap, $LDAP_BASE,
		"(&(uid=$username)(objectclass=isdepartmentadminof))");
        $info = ldap_get_entries($ldap, $sr);
	if ($info["count"] == 1){
		$isdepartmentadmin=true;
	}

	# Close and register variables
	ldap_close ($ldap);
	session_register ("isadmin");
	session_register ("isdepartmentadmin");
}

# Generate page - MAIN
print ("<head>\n");
print (" <link rel=\"stylesheet\" href=\"include/style.css\" type=\"text/css\">\n");
print ("</head>\n\n");
print ("<body topmargin=\"0\" bottommargin=\"0\" leftmargin=\"0\"".
	" rightmargin=\"0\" marginheight=\"0\" marginwidth=\"0\">\n");

if (!$prtmode){
	# Titlebar
	print (" <table width=100% height=100% border=0 cellspacing=0 cellpadding=0>\n");
	print ("  <tr width=100% bgcolor=#CDF6BD>\n");
	print ("   <td colspan=3 valign=top>\n");
	print ("    <table width=100% border=0 cellspacing=0 cellpadding=3>\n");
	print ("     <tr width=100%>\n");
#	print ("      <td><a class=maintitlebar ".
#		"href=\"$admin_base/main.php?plugin=welcome\">"._("Main")."</a> | ".
#		"<a class=maintitlebar href=\"javascript:showHelpPopup('$admin_base/$plugin/help/index$language.php?base=$admin_base')\">".
#		_("Help")."</a> | <a class=maintitlebar href=\"$admin_base/logout.php\">".
#		_("Logout")."</a>\n");
	print ("      <td><a class=maintitlebar ".
		"href=\"$admin_base/main.php?plugin=welcome\">"._("Main")."</a> | ".
		"<a class=maintitlebar href=\"javascript:showHelpPopup('$admin_base/include/help.php?plugin=$plugin&language=$language&base=$admin_base')\">".
		_("Help")."</a> | <a class=maintitlebar href=\"$admin_base/logout.php\">".
		_("Logout")."</a>\n");
	print ("      </td>\n");
	print ("      <td align=center>\n");

	if (file_exists ("$plugin/headline.php")){
		print ("       <span class=maintitlebar>");
		include ("$plugin/headline.php");
		print ("</b></span>\n");
	}

	print ("      </td>\n");
	print ("      <td align=right>\n");
	print ("       <span class=maintitlebar>"._("Logged in").": <b>$username</b></span>\n");
	print ("      </td>\n");
	print ("     </tr>\n");
	print ("    </table>\n");
	print ("   </td>\n");
	print ("  </tr>\n");
	print ("  <tr height=100%>\n");
	print ("   <td valign=\"top\" bgcolor=#e8fbe2><a href=\"http://www.gonicus.de\"><img src=\"images/go_logo.png\" border=0></a><br>\n");

	# Create menu structure
	generate_menu ();
	print ("   </td>\n");
	print ("   <td height=100% valign=top width=100%>\n");
}

# Create main page
print ("    <table height=100% border=0 cellpadding=0 cellspacing=0 width=100%>\n");
if (!$prtmode){
	print ("     <tr>\n");
	print ("      <td width=15 height=15 background=\"images/go_corner.png\"></td>\n");
	print ("      <td background=\"images/go_top.png\"></td>\n");
	print ("     </tr>\n");
}
print ("     <tr>\n");

if (!$prtmode){
	print ("      <td height=100% background=\"images/go_left.png\"></td>\n");
}

print ("      <td valign=top>\n");
if (file_exists ("$plugin/index.php")) {
	include ("$plugin/index.php");
}
print ("      </td>\n");
print ("     </tr>\n");
print ("    </table>\n");

print ("   </td>\n");
print ("  </tr>\n");
print (" </table>\n");
print ("</body>\n");
exit ();

?>

==> GOsa-1.0.1.tar.gz: gosa/main.php <==
<?php
/**************************************************************************
*                        GONICUS Server Administration                    *
*        Version 1.0.0  (C) 2002 Cajus Pollmeier <pollmeier@gonicus.de>   *
***************************************************************************
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation, version 2 of the License                *
*                                                                         *
***************************************************************************/

# Load session data and preset $parent_length
session_start ();
#error_reporting (65535);
error_reporting (0);
$parent_length= strlen (`pwd`);
header("Expires: Mon, 26 Jul 1997 05:00:00 GMT");
header("Last-Modified: " . gmdate("D, d M Y H:i:s") . " GMT"); 
header("Cache-Control: no-store, no-cache, must-revalidate");
header("Cache-Control: post-check=0, pre-check=0", false);
header("Pragma: no-cache");

print ("<script language=\"JavaScript\">\n");
print (" <!--\n");
print ("function showHelpPopup(page) {\n");
print (" window.open (page, 'newwindow', config='height=500, width=500, toolbar=no, menubar=no, scrollbars=yes, resizable=yes, location=no, directories=no, status=no');\n");
print ("}\n");
print (" -->\n");
print ("</script>\n");

# Redirect to login screen if not registered
if (!session_is_registered ("user")) {
	header ("Location: $admin_base/index.php");
	print ("\n\n");
	exit ();
}

# initialize side menu
if (!count($side_menu)){
        $side_menu= array ();
}

# Include menu subroutines
require ("include/setup.inc");
require ("include/common.inc");
require ("include/ldap.inc");
require ("include/menu.inc");
#require ("include/sieve-php.lib");

# Setup language and text domain for all plugins
if (!strlen($language)){
	$language=trim(get_language ($HTTP_ACCEPT_LANGUAGE));
}

putenv ("LANG=$language");
setlocale("LC_ALL", "");
bindTextDomain('main', './locale');
textDomain('main');
session_register ("language");

# Preset plugin to welcome.php
if (!isset ($plugin)) {
	$plugin= "welcome";
	$prtmode= false;
}

# Check for admin rights - only for the first time
if (!isset($isadmin)) {
	$isadmin= false;
	$isdepartmentadmin= false;
	if (!($ldap= ldap_con ($user,$password))) {
		print_red (_("Cannot bind to the ldap server: "));
		exit ();
	}

	# Try to write a dummy entry
	$entry= array ();
	$entry["objectclass"][]= "top";
	if (ldap_add ($ldap, "cn=admincheck,$LDAP_BASE", $entry)) {
		$isadmin= true;
		ldap_delete ($ldap, "cn=admincheck, $LDAP_BASE");
	}

	# is department admin?
	$sr=ldap_search ($ldap, $LDAP_BASE,
		"(&(uid=$username)(objectclass=isdepartmentadminof))");
        $info = ldap_get_entries($ldap, $sr);
	if ($info["count"] == 1){
		$isdepartmentadmin=true;
	}

	# Close and register variables
	ldap_close ($ldap);
	session_register ("isadmin");
	session_register ("isdepartmentadmin");
}

# Generate page - MAIN
print ("<head>\n");
print (" <link rel=\"stylesheet\" href=\"include/style.css\" type=\"text/css\">\n");
print ("</head>\n\n");
print ("<body topmargin=\"0\" bottommargin=\"0\" leftmargin=\"0\"".
	" rightmargin=\"0\" marginheight=\"0\" marginwidth=\"0\">\n");

if (!$prtmode){
	# Titlebar
	print (" <table width=100% height=100% border=0 cellspacing=0 cellpadding=0>\n");
	print ("  <tr width=100% bgcolor=#CDF6BD>\n");
	print ("   <td colspan=3 valign=top>\n");
	print ("    <table width=100% border=0 cellspacing=0 cellpadding=3>\n");
	print ("     <tr width=100%>\n");
#	print ("      <td><a class=maintitlebar ".
#		"href=\"$admin_base/main.php?plugin=welcome\">"._("Main")."</a> | ".
#		"<a class=maintitlebar href=\"javascript:showHelpPopup('$admin_base/$plugin/help/index$language.php?base=$admin_base')\">".
#		_("Help")."</a> | <a class=maintitlebar href=\"$admin_base/logout.php\">".
#		_("Logout")."</a>\n");
	print ("      <td><a class=maintitlebar ".
		"href=\"$admin_base/main.php?plugin=welcome\">"._("Main")."</a> | ".
		"<a class=maintitlebar href=\"javascript:showHelpPopup('$admin_base/include/help.inc?plugin=$plugin&language=$language&base=$admin_base')\">".
		_("Help")."</a> | <a class=maintitlebar href=\"$admin_base/logout.php\">".
		_("Logout")."</a>\n");
	print ("      </td>\n");
	print ("      <td align=center>\n");

	if (file_exists ("$plugin/headline.php")){
		print ("       <span class=maintitlebar>");
		include ("$plugin/headline.php");
		print ("</b></span>\n");
	}

	print ("      </td>\n");
	print ("      <td align=right>\n");
	print ("       <span class=maintitlebar>"._("Logged in").": <b>$username</b></span>\n");
	print ("      </td>\n");
	print ("     </tr>\n");
	print ("    </table>\n");
	print ("   </td>\n");
	print ("  </tr>\n");
	print ("  <tr height=100%>\n");
	print ("   <td valign=\"top\" bgcolor=#e8fbe2><a href=\"http://www.gonicus.de\"><img src=\"images/go_logo.png\" border=0></a><br>\n");

	# Create menu structure
	generate_menu ();
	print ("   </td>\n");
	print ("   <td height=100% valign=top width=100%>\n");
}

# Create main page
print ("    <table height=100% border=0 cellpadding=0 cellspacing=0 width=100%>\n");
if (!$prtmode){
	print ("     <tr>\n");
	print ("      <td width=15 height=15 background=\"images/go_corner.png\"></td>\n");
	print ("      <td background=\"images/go_top.png\"></td>\n");
	print ("     </tr>\n");
}
print ("     <tr>\n");

if (!$prtmode){
	print ("      <td height=100% background=\"images/go_left.png\"></td>\n");
}

print ("      <td valign=top>\n");
if (file_exists ("$plugin/index.php")) {
	include ("$plugin/index.php");
}
print ("      </td>\n");
print ("     </tr>\n");
print ("    </table>\n");

print ("   </td>\n");
print ("  </tr>\n");
print (" </table>\n");
print ("</body>\n");
exit ();

?>
